/*
  ==============================================================================

    This file was auto-generated!

    It contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#include "PluginProcessor.h"
#include "PluginEditor.h"

#ifdef NICK_CHANGES
String documentsFolder()
{
    File docsFolder = File::getSpecialLocation(File::userDocumentsDirectory);
    String path = docsFolder.getFullPathName();
    return path;
}

void MicPluginTestAudioProcessorEditor::startRecording()
{
    if (! RuntimePermissions::isGranted (RuntimePermissions::writeExternalStorage))
    {
        SafePointer<MicPluginTestAudioProcessorEditor> safeThis (this);
        
        RuntimePermissions::request (RuntimePermissions::writeExternalStorage,
                                     [safeThis] (bool granted) mutable
                                     {
                                         if (granted)
                                             safeThis->startRecording();
                                     });
        return;
    }
    
#if (JUCE_ANDROID || JUCE_IOS)
    auto parentDir = File::getSpecialLocation (File::tempDirectory);
#else
    auto parentDir = File::getSpecialLocation (File::userDocumentsDirectory);
#endif
#if 1
    String path = documentsFolder();
    path += "/sample.wav";
    lastRecording = File(path);
#endif
    recorder.startRecording (lastRecording);
    
    recordSampleButton.setButtonText ("Stop");
    recordingThumbnail.setDisplayFullThumbnail (false);
}


void MicPluginTestAudioProcessorEditor::stopRecording()
{
    recorder.stop();
    recordSampleButton.setButtonText ("Record");
    recordingThumbnail.setDisplayFullThumbnail (true);
}

#endif

//==============================================================================
MicPluginTestAudioProcessorEditor::MicPluginTestAudioProcessorEditor (MicPluginTestAudioProcessor& p)
    : AudioProcessorEditor (&p), processor (p)
{
    // Make sure that before the constructor has finished, you've set the
    // editor's size to whatever you need it to be.
#ifdef NICK_CHANGES
    recordSampleButton.onClick = [this] {
        if (recorder.isRecording()) {
            stopRecording();
        } else {
            startRecording();
        }
    };
    addAndMakeVisible(recordSampleButton);
#ifndef JUCE_DEMO_RUNNER
    RuntimePermissions::request (RuntimePermissions::recordAudio,
                                 [this] (bool granted)
                                 {
                                     int numInputChannels = granted ? 2 : 0;
                                     audioDeviceManager.initialise (numInputChannels, 2, nullptr, true, {}, nullptr);
                                 });
#endif

    addAndMakeVisible (recordingThumbnail);
    addAndMakeVisible (liveAudioScroller);
    audioDeviceManager.addAudioCallback(&liveAudioScroller);
    audioDeviceManager.addAudioCallback (&recorder);

#endif
    setSize (400, 300);
}

MicPluginTestAudioProcessorEditor::~MicPluginTestAudioProcessorEditor()
{
}

//==============================================================================
void MicPluginTestAudioProcessorEditor::paint (Graphics& g)
{
#ifndef NICK_CHANGES
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll (getLookAndFeel().findColour (ResizableWindow::backgroundColourId));

    g.setColour (Colours::white);
    g.setFont (15.0f);
    g.drawFittedText ("Hello World!", getLocalBounds(), Justification::centred, 1);
#endif
}

void MicPluginTestAudioProcessorEditor::resized()
{
#ifdef NICK_CHANGES
    Grid grid;
    
    using Track = Grid::TrackInfo;
    juce::Array<GridItem> items;
    int row = 1, col = 1;
    
    items.add(GridItem (recordingThumbnail).withRow({row++}).withColumn({col}));
    items.add(GridItem (recordSampleButton).withRow({row++}).withColumn({col}));

    grid.templateColumns = {1_fr};
    grid.templateRows = {1_fr, 1_fr};
    
    
    //recordingThumbnail
    grid.items.addArray(items);
    

    Rectangle<int>localBounds = getLocalBounds();
    grid.performLayout (localBounds);
#endif
}
